Re: [PATCH 12/15] [GSOC] cat-file: reuse ref-filter logic
- From
Christian Couder <christian.couder@gmail.com>
- Date
- Jul 2, 2021, 13:45 UTC
- Message-ID
- <CAP8UFD0P5eiwxKvot_5+izEjscyGw+F4QFN72BmgHNhi9V5S1w@mail.gmail.com>
- In-Reply-To
- <877di8al8n.fsf@evledraar.gmail.com>
On Fri, Jul 2, 2021 at 3:39 PM Ævar Arnfjörð Bjarmason <avarab@gmail.com> wrote:
> > On Thu, Jul 01 2021, ZheNing Hu via GitGitGadget wrote:
Show 17 quoted lines
> > The performance for `git cat-file --batch-all-objects > > --batch-check` on the Git repository itself with performance > > testing tool `hyperfine` changes from 669.4 ms ± 31.1 ms to > > 1.134 s ± 0.063 s. > > > > The performance for `git cat-file --batch-all-objects --batch > >>/dev/null` on the Git repository itself with performance testing > > tool `time` change from "27.37s user 0.29s system 98% cpu 28.089 > > total" to "33.69s user 1.54s system 87% cpu 40.258 total". > > This new feature is really nice, but that's a really bad performance > regression. A lot of software in the wild relies on "cat-file --batch" > to be *the* performant interface to git for mass-extrction of object > data. > > That's in increase of ~70% and ~20%, respectively. Have you dug into > (e.g. with a profiler) where we're now spending all this time?
Yeah, I think it's better to discuss this performance issue as part of the discussion of this series, instead of as part of the discussion of the blog posts.